Merge branch 'master' of https://github.com/ROCm-Developer-Tools/HIP into feature_get_alignment_and_size_from_metadata

This commit is contained in:
Alex Voicu
2018-11-01 23:17:27 +00:00
17 changed files with 216 additions and 162 deletions
@@ -84,6 +84,9 @@ class Bundled_code_header {
std::copy_n(f + y.header.offset, y.header.bundle_sz, std::back_inserter(y.blob));
it += y.header.triple_sz;
x.bundled_code_size = std::max(x.bundled_code_size,
y.header.offset + y.header.bundle_sz);
}
return true;
@@ -123,6 +126,8 @@ class Bundled_code_header {
// MANIPULATORS
Bundled_code_header& operator=(const Bundled_code_header&) = default;
Bundled_code_header& operator=(Bundled_code_header&&) = default;
size_t bundled_code_size = 0;
};
// CREATORS
@@ -876,6 +876,15 @@ static void __threadfence_system()
__atomic_work_item_fence(0, __memory_order_seq_cst, __memory_scope_all_svm_devices);
}
// abort
__device__
inline
__attribute__((weak))
void abort() {
return __builtin_trap();
}
#endif // __HCC_OR_HIP_CLANG__
#ifdef __HCC__
+1 -2
View File
@@ -181,8 +181,7 @@ extern int HIP_TRACE_API;
#define __HCC_C__
#endif
// abort
__device__ void abort();
__host__ inline void* __get_dynamicgroupbaseptr() { return nullptr; }
#if __HIP_ARCH_GFX701__ == 0
+2 -2
View File
@@ -94,7 +94,7 @@ typedef struct ihipModule_t* hipModule_t;
typedef struct ihipModuleSymbol_t* hipFunction_t;
struct hipFuncAttributes {
typedef struct hipFuncAttributes {
int binaryVersion;
int cacheModeCA;
size_t constSizeBytes;
@@ -105,7 +105,7 @@ struct hipFuncAttributes {
int preferredShmemCarveout;
int ptxVersion;
size_t sharedSizeBytes;
};
} hipFuncAttributes;
typedef struct ihipEvent_t* hipEvent_t;